package polish_community_group_11.polish_community.event.controllers;

import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import polish_community_group_11.polish_community.event.services.EventRepository;

@Controller
public class EventController {

    // Inject the EventRepository service to handle event-related data operations
    private EventRepository eventService;

    // Constructor-based dependency injection for EventRepository
    public EventController(EventRepository eventService){
        this.eventService = eventService;
    }

    // Controller method to handle GET requests for the "/event" URL
    @GetMapping("/event")
    public ModelAndView getAllEvents() {
        // Create a ModelAndView object to handle both the view (HTML) and data
        ModelAndView modelAndView = new ModelAndView("event/event");

        // Add the list of all events to the model object, which will be passed to the Thymeleaf template
        // 'eventService.getAllEvents()' fetches all the event data from the database
        modelAndView.addObject("events", eventService.getAllEvents());

        // Return the ModelAndView object, which contains the view name ("event/event") and the data (events)
        // This tells Spring to render the "event/event" Thymeleaf template and pass the "events" data
        return modelAndView;  // Thymeleaf template will use this data to render the event details
    }

    /**
     * Handles HTTP GET request for fetching event details by event ID.
     *
     * @param event_id the unique identifier of the event to fetch
     * @return ModelAndView object with the event details view and event data
     */
    @GetMapping("event/{event_id}") // Mapping URL pattern with the event ID as a path variable
    public ModelAndView getEventDetails(@PathVariable int event_id) {

        // Create a new ModelAndView object and associate it with the 'event-detail' view
        ModelAndView modelAndView = new ModelAndView("event/event-detail");

        // Add the event object (fetched using the event ID) to the model
        modelAndView.addObject("event", eventService.getEventById(event_id));

        // Return the populated ModelAndView object, which will render the event details view
        return modelAndView;
    }
}
